==> cdk8s-plus-17-1.0.0b27.tar.gz: package/lib/service.d.ts <==
import * as cdk8s from 'cdk8s';
import { Construct } from 'constructs';
import { ResourceProps, Resource } from './base';
import { Deployment } from './deployment';
import * as k8s from './imports/k8s';
/**
 * Properties for initialization of `Service`.
 *
 * @stability stable
 */
export interface ServiceProps extends ResourceProps {
    /**
     * The IP address of the service and is usually assigned randomly by the master.
     *
     * If an address is specified manually and is not in use by others, it
     * will be allocated to the service; otherwise, creation of the service will
     * fail. This field can not be changed through updates. Valid values are
     * "None", empty string (""), or a valid IP address. "None" can be specified
     * for headless services when proxying is not required. Only applies to types
     * ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName.
     *
     * @default - Automatically assigned.
     * @see https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
     * @stability stable
     */
    readonly clusterIP?: string;
    /**
     * A list of IP addresses for which nodes in the cluster will also accept traffic for this service.
     *
     * These IPs are not managed by Kubernetes. The user
     * is responsible for ensuring that traffic arrives at a node with this IP. A
     * common example is external load-balancers that are not part of the
     * Kubernetes system.
     *
     * @default - No external IPs.
     * @stability stable
     */
    readonly externalIPs?: string[];
    /**
     * Determines how the Service is exposed.
     *
     * More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
     *
     * @default ServiceType.ClusterIP
     * @stability stable
     */
    readonly type?: ServiceType;
    /**
     * The port exposed by this service.
     *
     * More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
     *
     * @stability stable
     */
    readonly ports?: ServicePort[];
    /**
     * The externalName to be used when ServiceType.EXTERNAL_NAME is set.
     *
     * @default - No external name.
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * A list of CIDR IP addresses, if specified and supported by the platform, will restrict traffic through the cloud-provider load-balancer to the specified client IPs.
     *
     * More info: https://kubernetes.io/docs/tasks/access-application-cluster/configure-cloud-provider-firewall/
     *
     * @stability stable
     */
    readonly loadBalancerSourceRanges?: string[];
}
/**
 * For some parts of your application (for example, frontends) you may want to expose a Service onto an external IP address, that's outside of your cluster.
 *
 * Kubernetes ServiceTypes allow you to specify what kind of Service you want.
 * The default is ClusterIP.
 *
 * @stability stable
 */
export declare enum ServiceType {
    /**
     * Exposes the Service on a cluster-internal IP.
     *
     * Choosing this value makes the Service only reachable from within the cluster.
     * This is the default ServiceType
     *
     * @stability stable
     */
    CLUSTER_IP = "ClusterIP",
    /**
     * Exposes the Service on each Node's IP at a static port (the NodePort).
     *
     * A ClusterIP Service, to which the NodePort Service routes, is automatically created.
     * You'll be able to contact the NodePort Service, from outside the cluster,
     * by requesting <NodeIP>:<NodePort>.
     *
     * @stability stable
     */
    NODE_PORT = "NodePort",
    /**
     * Exposes the Service externally using a cloud provider's load balancer.
     *
     * NodePort and ClusterIP Services, to which the external load balancer routes,
     * are automatically created.
     *
     * @stability stable
     */
    LOAD_BALANCER = "LoadBalancer",
    /**
     * Maps the Service to the contents of the externalName field (e.g. foo.bar.example.com), by returning a CNAME record with its value. No proxying of any kind is set up.
     *
     * > Note: You need either kube-dns version 1.7 or CoreDNS version 0.0.8 or higher to use the ExternalName type.
     *
     * @stability stable
     */
    EXTERNAL_NAME = "ExternalName"
}
/**
 * An abstract way to expose an application running on a set of Pods as a network service.
 *
 * With Kubernetes you don't need to modify your application to use an unfamiliar service discovery mechanism.
 * Kubernetes gives Pods their own IP addresses and a single DNS name for a set of Pods, and can load-balance across them.
 *
 * For example, consider a stateless image-processing backend which is running with 3 replicas. Those replicas are fungible—frontends do not care which backend they use.
 * While the actual Pods that compose the backend set may change, the frontend clients should not need to be aware of that,
 * nor should they need to keep track of the set of backends themselves.
 * The Service abstraction enables this decoupling.
 *
 * If you're able to use Kubernetes APIs for service discovery in your application, you can query the API server for Endpoints,
 * that get updated whenever the set of Pods in a Service changes. For non-native applications, Kubernetes offers ways to place a network port
 * or load balancer in between your application and the backend Pods.
 *
 * @stability stable
 */
export declare class Service extends Resource {
    /**
     * The IP address of the service and is usually assigned randomly by the master.
     *
     * @stability stable
     */
    readonly clusterIP?: string;
    /**
     * Determines how the Service is exposed.
     *
     * @stability stable
     */
    readonly type: ServiceType;
    /**
     * The externalName to be used for EXTERNAL_NAME types.
     *
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * The underlying cdk8s API object.
     *
     * @see base.Resource.apiObject
     * @stability stable
     */
    protected readonly apiObject: cdk8s.ApiObject;
    private readonly _externalIPs;
    private readonly _selector;
    private readonly _ports;
    private readonly _loadBalancerSourceRanges?;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props?: ServiceProps);
    /**
     * Returns the labels which are used to select pods for this service.
     *
     * @stability stable
     */
    get selector(): Record<string, string>;
    /**
     * Ports for this service.
     *
     * Use `serve()` to expose additional service ports.
     *
     * @stability stable
     */
    get ports(): ServicePort[];
    /**
     * Associate a deployment to this service.
     *
     * If not targetPort is specific in the portOptions, then requests will be routed
     * to the port exposed by the first container in the deployment's pods.
     * The deployment's `labelSelector` will be used to select pods.
     *
     * @param deployment The deployment to expose.
     * @param port The external port.
     * @param options Optional settings for the port.
     * @stability stable
     */
    addDeployment(deployment: Deployment, port: number, options?: ServicePortOptions): void;
    /**
     * Services defined using this spec will select pods according the provided label.
     *
     * @param label The label key.
     * @param value The label value.
     * @stability stable
     */
    addSelector(label: string, value: string): void;
    /**
     * Configure a port the service will bind to.
     *
     * This method can be called multiple times.
     *
     * @param port The port definition.
     * @stability stable
     */
    serve(port: number, options?: ServicePortOptions): void;
    /**
     * @internal
     */
    _toKube(): k8s.ServiceSpec;
}
/**
 * @stability stable
 */
export declare enum Protocol {
    /**
     * @stability stable
     */
    TCP = "TCP",
    /**
     * @stability stable
     */
    UDP = "UDP",
    /**
     * @stability stable
     */
    SCTP = "SCTP"
}
/**
 * @stability stable
 */
export interface ServicePortOptions {
    /**
     * The name of this port within the service.
     *
     * This must be a DNS_LABEL. All
     * ports within a ServiceSpec must have unique names. This maps to the 'Name'
     * field in EndpointPort objects. Optional if only one ServicePort is defined
     * on this service.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The port on each node on which this service is exposed when type=NodePort or LoadBalancer.
     *
     * Usually assigned by the system. If specified, it will be
     * allocated to the service if unused or else creation of the service will
     * fail. Default is to auto-allocate a port if the ServiceType of this Service
     * requires one.
     *
     * @default to auto-allocate a port if the ServiceType of this Service
     * requires one.
     * @see https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
     * @stability stable
     */
    readonly nodePort?: number;
    /**
     * The IP protocol for this port.
     *
     * Supports "TCP", "UDP", and "SCTP". Default is TCP.
     *
     * @default Protocol.TCP
     * @stability stable
     */
    readonly protocol?: Protocol;
    /**
     * The port number the service will redirect to.
     *
     * @default - The value of `port` will be used.
     * @stability stable
     */
    readonly targetPort?: number;
}
/**
 * Definition of a service port.
 *
 * @stability stable
 */
export interface ServicePort extends ServicePortOptions {
    /**
     * The port number the service will bind to.
     *
     * @stability stable
     */
    readonly port: number;
}

==> cdk8s-plus-21-1.0.0b54.tar.gz: package/lib/service.d.ts <==
import * as cdk8s from 'cdk8s';
import { Construct } from 'constructs';
import { ResourceProps, Resource } from './base';
import { Deployment } from './deployment';
import * as k8s from './imports/k8s';
import { IngressV1Beta1 } from './ingress-v1beta1';
/**
 * Properties for initialization of `Service`.
 *
 * @stability stable
 */
export interface ServiceProps extends ResourceProps {
    /**
     * The IP address of the service and is usually assigned randomly by the master.
     *
     * If an address is specified manually and is not in use by others, it
     * will be allocated to the service; otherwise, creation of the service will
     * fail. This field can not be changed through updates. Valid values are
     * "None", empty string (""), or a valid IP address. "None" can be specified
     * for headless services when proxying is not required. Only applies to types
     * ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName.
     *
     * @default - Automatically assigned.
     * @see https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
     * @stability stable
     */
    readonly clusterIP?: string;
    /**
     * A list of IP addresses for which nodes in the cluster will also accept traffic for this service.
     *
     * These IPs are not managed by Kubernetes. The user
     * is responsible for ensuring that traffic arrives at a node with this IP. A
     * common example is external load-balancers that are not part of the
     * Kubernetes system.
     *
     * @default - No external IPs.
     * @stability stable
     */
    readonly externalIPs?: string[];
    /**
     * Determines how the Service is exposed.
     *
     * More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
     *
     * @default ServiceType.ClusterIP
     * @stability stable
     */
    readonly type?: ServiceType;
    /**
     * The port exposed by this service.
     *
     * More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
     *
     * @stability stable
     */
    readonly ports?: ServicePort[];
    /**
     * The externalName to be used when ServiceType.EXTERNAL_NAME is set.
     *
     * @default - No external name.
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * A list of CIDR IP addresses, if specified and supported by the platform, will restrict traffic through the cloud-provider load-balancer to the specified client IPs.
     *
     * More info: https://kubernetes.io/docs/tasks/access-application-cluster/configure-cloud-provider-firewall/
     *
     * @stability stable
     */
    readonly loadBalancerSourceRanges?: string[];
}
/**
 * Options for exposing a service using an ingress.
 *
 * @stability stable
 */
export interface ExposeServiceViaIngressOptions {
    /**
     * The ingress to add rules to.
     *
     * @default - An ingress will be automatically created.
     * @stability stable
     */
    readonly ingress?: IngressV1Beta1;
}
/**
 * For some parts of your application (for example, frontends) you may want to expose a Service onto an external IP address, that's outside of your cluster.
 *
 * Kubernetes ServiceTypes allow you to specify what kind of Service you want.
 * The default is ClusterIP.
 *
 * @stability stable
 */
export declare enum ServiceType {
    /**
     * Exposes the Service on a cluster-internal IP.
     *
     * Choosing this value makes the Service only reachable from within the cluster.
     * This is the default ServiceType
     *
     * @stability stable
     */
    CLUSTER_IP = "ClusterIP",
    /**
     * Exposes the Service on each Node's IP at a static port (the NodePort).
     *
     * A ClusterIP Service, to which the NodePort Service routes, is automatically created.
     * You'll be able to contact the NodePort Service, from outside the cluster,
     * by requesting <NodeIP>:<NodePort>.
     *
     * @stability stable
     */
    NODE_PORT = "NodePort",
    /**
     * Exposes the Service externally using a cloud provider's load balancer.
     *
     * NodePort and ClusterIP Services, to which the external load balancer routes,
     * are automatically created.
     *
     * @stability stable
     */
    LOAD_BALANCER = "LoadBalancer",
    /**
     * Maps the Service to the contents of the externalName field (e.g. foo.bar.example.com), by returning a CNAME record with its value. No proxying of any kind is set up.
     *
     * > Note: You need either kube-dns version 1.7 or CoreDNS version 0.0.8 or higher to use the ExternalName type.
     *
     * @stability stable
     */
    EXTERNAL_NAME = "ExternalName"
}
/**
 * Options to add a deployment to a service.
 *
 * @stability stable
 */
export interface AddDeploymentOptions extends ServicePortOptions {
    /**
     * The port number the service will bind to.
     *
     * @default - Copied from the first container of the deployment.
     * @stability stable
     */
    readonly port?: number;
}
/**
 * An abstract way to expose an application running on a set of Pods as a network service.
 *
 * With Kubernetes you don't need to modify your application to use an unfamiliar service discovery mechanism.
 * Kubernetes gives Pods their own IP addresses and a single DNS name for a set of Pods, and can load-balance across them.
 *
 * For example, consider a stateless image-processing backend which is running with 3 replicas. Those replicas are fungible—frontends do not care which backend they use.
 * While the actual Pods that compose the backend set may change, the frontend clients should not need to be aware of that,
 * nor should they need to keep track of the set of backends themselves.
 * The Service abstraction enables this decoupling.
 *
 * If you're able to use Kubernetes APIs for service discovery in your application, you can query the API server for Endpoints,
 * that get updated whenever the set of Pods in a Service changes. For non-native applications, Kubernetes offers ways to place a network port
 * or load balancer in between your application and the backend Pods.
 *
 * @stability stable
 */
export declare class Service extends Resource {
    /**
     * The IP address of the service and is usually assigned randomly by the master.
     *
     * @stability stable
     */
    readonly clusterIP?: string;
    /**
     * Determines how the Service is exposed.
     *
     * @stability stable
     */
    readonly type: ServiceType;
    /**
     * The externalName to be used for EXTERNAL_NAME types.
     *
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * The underlying cdk8s API object.
     *
     * @see base.Resource.apiObject
     * @stability stable
     */
    protected readonly apiObject: cdk8s.ApiObject;
    private readonly _externalIPs;
    private readonly _selector;
    private readonly _ports;
    private readonly _loadBalancerSourceRanges?;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props?: ServiceProps);
    /**
     * Expose a service via an ingress using the specified path.
     *
     * @param path The path to expose the service under.
     * @param options Additional options.
     * @returns The `Ingress` resource that was used.
     * @stability stable
     */
    exposeViaIngress(path: string, options?: ExposeServiceViaIngressOptions): IngressV1Beta1;
    /**
     * Returns the labels which are used to select pods for this service.
     *
     * @stability stable
     */
    get selector(): Record<string, string>;
    /**
     * Ports for this service.
     *
     * Use `serve()` to expose additional service ports.
     *
     * @stability stable
     */
    get ports(): ServicePort[];
    /**
     * Associate a deployment to this service.
     *
     * If not targetPort is specific in the portOptions, then requests will be routed
     * to the port exposed by the first container in the deployment's pods.
     * The deployment's `labelSelector` will be used to select pods.
     *
     * @param deployment The deployment to expose.
     * @param options Optional settings for the port.
     * @stability stable
     */
    addDeployment(deployment: Deployment, options?: AddDeploymentOptions): void;
    /**
     * Services defined using this spec will select pods according the provided label.
     *
     * @param label The label key.
     * @param value The label value.
     * @stability stable
     */
    addSelector(label: string, value: string): void;
    /**
     * Configure a port the service will bind to.
     *
     * This method can be called multiple times.
     *
     * @param port The port definition.
     * @stability stable
     */
    serve(port: number, options?: ServicePortOptions): void;
    /**
     * @internal
     */
    _toKube(): k8s.ServiceSpec;
}
/**
 * @stability stable
 */
export declare enum Protocol {
    /**
     * @stability stable
     */
    TCP = "TCP",
    /**
     * @stability stable
     */
    UDP = "UDP",
    /**
     * @stability stable
     */
    SCTP = "SCTP"
}
/**
 * @stability stable
 */
export interface ServicePortOptions {
    /**
     * The name of this port within the service.
     *
     * This must be a DNS_LABEL. All
     * ports within a ServiceSpec must have unique names. This maps to the 'Name'
     * field in EndpointPort objects. Optional if only one ServicePort is defined
     * on this service.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The port on each node on which this service is exposed when type=NodePort or LoadBalancer.
     *
     * Usually assigned by the system. If specified, it will be
     * allocated to the service if unused or else creation of the service will
     * fail. Default is to auto-allocate a port if the ServiceType of this Service
     * requires one.
     *
     * @default - auto-allocate a port if the ServiceType of this Service requires one.
     * @see https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
     * @stability stable
     */
    readonly nodePort?: number;
    /**
     * The IP protocol for this port.
     *
     * Supports "TCP", "UDP", and "SCTP". Default is TCP.
     *
     * @default Protocol.TCP
     * @stability stable
     */
    readonly protocol?: Protocol;
    /**
     * The port number the service will redirect to.
     *
     * @default - The value of `port` will be used.
     * @stability stable
     */
    readonly targetPort?: number;
}
/**
 * Definition of a service port.
 *
 * @stability stable
 */
export interface ServicePort extends ServicePortOptions {
    /**
     * The port number the service will bind to.
     *
     * @stability stable
     */
    readonly port: number;
}
